#include <iostream>
#include "poisson.h"
const int Size = 1000;

const double Min = 0.0, Max = 1.0;

int main() {
    omp_set_num_threads(2); 
	__cilkrts_set_param("nworkers","2");
    // prepare problem
    Problem p(Size, Min, Max);
    std :: cout << "Problem prepared" << std :: endl;
    // time measurement
    double time;

    // 0. Serial Gauss-Seidel solver
    /*
	SerialSeidelSolver serial;
    serial.SetProblem(&p);
    time = serial.RunAndMeasure();
    std :: cout << "Serial Gauss-Seidel, time = " << time << std :: endl;
	*/

	// 1. Parallel wave front solver with OpenMP
	p.ReinitProblem();
    OpenMPWaveSolver omp_w;
    omp_w.SetProblem(&p);
    time = omp_w.RunAndMeasure();
    std :: cout << "OpenMP wave, time = " << time << std :: endl;
	
	// 2. Parallel wave front solver with OpenMP
	/*
    p.ReinitProblem();
    CilkWaveSolver cilk_w;
    cilk_w.SetProblem(&p);
    time = cilk_w.RunAndMeasure();
    std :: cout << "Cilk wave, time = " << time << std :: endl;
	*/

	return 0;
}
